/**********************************************************************
* File: I2c.c
* Devices: TMS320F280x, TMS320F280xx
* Author: David M. Alter, Texas Instruments Inc.
* History:
*   02/18/08 - original (D. Alter)
**********************************************************************/
#include "F28035_example.h"				// Main include file


/**********************************************************************
* Function: I2cInit()
* Description: Initializes the I2C Module.
**********************************************************************/
void I2cInit(void)
{
	I2caRegs.I2CMDR.bit.IRS = 0;		// Reset the I2C module

// I2C addresses
	I2caRegs.I2COAR = 0x0002;			// My Own Address


// Configure for 400 kHz bitrate with 60 MHz SYSCLKOUT
// I2C bus clock = I2C_module_clock/[(I2CCLKL + d) + (I2CCLKH + d)]
// where d=5 when I2CPSC = 5.
	I2caRegs.I2CPSC.all = 5;			// SYSCLKOUT/(IPSC+1) = 10 MHz module clock (must be 7-12 Mhz)
	I2caRegs.I2CCLKL = 10;				// Allow more time when clock is low to allow SDA to change
	I2caRegs.I2CCLKH = 5;				// Need less time when clock is hi

// General configuration
	I2caRegs.I2CFFTX.bit.I2CFFEN = 0;	// FIFO mode disabled
    I2caRegs.I2CIER.all = 0x0000;		// No interrupts enabled
    I2caRegs.I2CMDR.bit.IRS = 1;		// Take I2C out of reset

} // end of I2cInit()


/**********************************************************************
* Function: I2cTx()
* Description: Transmits dummy data on the I2C Module.
**********************************************************************/
void I2cTx(void)
{
	I2caRegs.I2CSAR = 0x0001;			// 10-bit Address of slave being transmitted to
	I2caRegs.I2CCNT = 1;				// Transmit count (1 = 1 word)
	I2caRegs.I2CSTR.bit.SCD = 1;		// Clear the SCD bit (stop condition bit)

	I2caRegs.I2CMDR.all = 0x2F20;		// DLB=0
//	I2caRegs.I2CMDR.all = 0x2F60;		// DLB=1
// bit 15        0:      NACKMOD, 0 = SEND acknowledge
// bit 14        0:      FREE, 0 = halt on emulation suspend
// bit 13        1:      STT, 1 = start transmission
// bit 12        0:      reserved
// bit 11        1:      STP, 1 = generate stop condition when I2CCNT = 0
// bit 10        1:      MST, 1 = master mode
// bit 9         1:      TRX, 1 = transmitter mode
// bit 8         1:      XA, 1 = 10-bit addressing, 0 = 7-bit addressing
// bit 7         0:      RM, 0 = nonrepeat mode
// bit 6         0:      DLB, digital loopback, 0 = disabled, 1 = enabled
// bit 5         1:      IRS, 1 = normal operation, 0 = reset
// bit 4         0:      STB, 0 = START byte mode disabled
// bit 3         0:      FDF, 0 = Free data format mode disabled
// bit 2-0       000:    BC, 000 = 8 bits per data byte

	I2caRegs.I2CDXR = 0xAA;				// Data to be sent

} // end of I2cTx()

void I2cWait(void)
{
   // Wait until the STP bit is cleared from any previous master communication.

	while(I2caRegs.I2CSTR.bit.SCD == 0 && I2caRegs.I2CSTR.bit.NACK == 0);	// Wait for a stop condition or a NACK
 
} // end of I2cWait()

//--- end of file -----------------------------------------------------
